@@ -12,10 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "actiongroup.h"
 #include "appinfo.h"
-#include "application.h"
-#include "applicationcommandline.h"
 #include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
@@ -27,15 +24,21 @@
 #include "dbusaddress.h"
 #include "dbusauthobserver.h"
 #include "dbusconnection.h"
+#include "dbuserror.h"
 #include "dbuserrorutils.h"
+#include "dbusinterfacevtable.h"
 #include "dbusintrospection.h"
 #include "dbusmessage.h"
 #include "dbusmethodinvocation.h"
 #include "dbusownname.h"
 #include "dbusproxy.h"
 #include "dbusserver.h"
+#include "dbussubtreevtable.h"
 #include "dbusutils.h"
 #include "dbuswatchname.h"
+#ifndef G_OS_WIN32
+#include "desktopappinfo.h"
+#endif //G_OS_WIN32
 #include "drive.h"
 #include "emblem.h"
 #include "emblemedicon.h"
@@ -74,7 +77,6 @@
 #include "resolver.h"
 #include "seekable.h"
 #include "settings.h"
-#include "settingsbackend.h"
 #include "socket.h"
 #include "socketaddress.h"
 #include "socketaddressenumerator.h"
@@ -86,18 +88,31 @@
 #include "socketservice.h"
 #include "srvtarget.h"
 #include "tcpconnection.h"
-#include "threadedsocketservice.h"
 #include "themedicon.h"
+#include "threadedsocketservice.h"
+#ifndef G_OS_WIN32
+#include "unixconnection.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixcredentialsmessage.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixfdlist.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixfdmessage.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixinputstream.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixoutputstream.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "unixsocketaddress.h"
+#endif //G_OS_WIN32
 #include "volume.h"
 #include "volumemonitor.h"
-#include "desktopappinfo.h"
-#include "unixconnection.h"
-#include "unixcredentialsmessage.h"
-#include "unixfdlist.h"
-#include "unixfdmessage.h"
-#include "unixinputstream.h"
-#include "unixoutputstream.h"
-#include "unixsocketaddress.h"
 
 extern "C"
 {
@@ -105,8 +120,6 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType g_app_launch_context_get_type(void);
-GType g_application_get_type(void);
-GType g_application_command_line_get_type(void);
 GType g_dbus_auth_observer_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
@@ -184,6 +197,7 @@ GType g_volume_monitor_get_type(void);
 //Declarations of the *_error_quark() functions:
 
 GQuark g_dbus_error_quark(void);
+GQuark g_io_error_quark(void);
 GQuark g_resolver_error_quark(void);
 } // extern "C"
 
@@ -191,8 +205,6 @@ GQuark g_resolver_error_quark(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class ApplicationCommandLine_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio { namespace DBus {  class AuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -272,13 +284,12 @@ namespace Gio {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(g_dbus_error_quark(), &Gio::Error::throw_func);
-  Glib::Error::register_domain(g_resolver_error_quark(), &Gio::ResolverError::throw_func);
+  Glib::Error::register_domain(g_dbus_error_quark(), &::Gio::DBus::Error::throw_func);
+  Glib::Error::register_domain(g_io_error_quark(), &::Gio::Error::throw_func);
+  Glib::Error::register_domain(g_resolver_error_quark(), &::Gio::ResolverError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
-  Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
-  Glib::wrap_register(g_application_command_line_get_type(), &Gio::ApplicationCommandLine_Class::wrap_new);
   Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBus::AuthObserver_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
@@ -355,8 +366,6 @@ void wrap_init()
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
-  Gio::Application::get_type();
-  Gio::ApplicationCommandLine::get_type();
   Gio::DBus::AuthObserver::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
